@@ -28,7 +28,7 @@ use Class::MOP;
 
 use Scalar::Util qw(refaddr);
 
-our $VERSION = '1.99_04';
+our $VERSION = '1.99_05';
 
 coerce 'Chart::Clicker::Renderer'
     => from 'Str'
@@ -153,7 +153,7 @@ sub draw {
 }
 
 override('prepare', sub {
-    my ($self, $driver, $standalone) = @_;
+    my ($self, $driver) = @_;
 
     # We check visible in these components because it's a waste to add them
     # if we aren't showing them.
@@ -259,16 +259,6 @@ override('prepare', sub {
     super;
 });
 
-around('prepare', sub {
-    my ($cont, $class, $driver) = @_;
-
-    my $standalone = 0;
-    unless(defined($driver)) {
-        $standalone = 1;
-    }
-    $cont->($class, $driver, $standalone);
-});
-
 sub get_datasets_for_context {
     my ($self, $name) = @_;
 
