@@ -6,7 +6,6 @@ use Moose::Util::TypeConstraints;
 use Chart::Clicker;
 use Chart::Clicker::Axis;
 use Chart::Clicker::Renderer::Line;
-use Chart::Clicker::Util;
 
 has 'domain_axis' => (
     is => 'rw',
@@ -19,6 +18,16 @@ has 'domain_axis' => (
         )
     }
 );
+has 'markers' => (
+    metaclass => 'Collection::Array',
+    is => 'rw',
+    isa => 'ArrayRef[Chart::Clicker::Data::Marker]',
+    default => sub { [] },
+    provides => {
+        'count' => 'marker_count',
+        'push'  => 'add_marker'
+    }
+);
 has 'name' => (
     is => 'rw',
     isa => 'Str',
